============
Introduction
============

This is Pelicanfly, a plugin for `Pelican`__ that lets you type things like ``i
♥ :icon-coffee:`` in your `Markdown`__ documents and have the icon prefixed tag
come out as little icons in the browser. It provides a minimal extension to
Markdown and a plugin for pelican.

The pelican plugin hacks in some static assets to make this work from pelican
"out of the box".  If you just want the Markdown extension, it is available
`separately`__.  Pelicanfly offers shorthand codes for adding `FontAwesome`__
icons to Markdown documents under Pelican.

__ `http://daringfireball.net/projects/markdown/`_
__ `http://docs.getpelican.com/`_
__ `http://bmcorser.github.com/markdown-fontawesome/`_
__ `http://fortawesome.github.io/Font-Awesome/`_

It's probably going to work in a better way by version 0.3.
